@@ -327,7 +327,7 @@ public:
     void groupAssetMultiKeyframeCommand(const ObjectId &id, const QString &assetId, const QList<QModelIndex> &indexes, GenTime pos,
                                         const QStringList &sourceValues, const QStringList &values, QUndoCommand *command);
     /** @brief Remove all effect instances in a group */
-    void removeGroupEffect(const ObjectId &id, const QString &assetId);
+    void removeGroupEffect(const ObjectId &id, const QString &assetId, int originalId);
     /** @brief Disable/enable all instance of an effect in a group */
     void applyEffectDisableToGroup(const ObjectId &id, const QString &assetId, bool disable, Fun &undo, Fun &redo);
     /** @brief Returns true if all ui elements have been initialized */
@@ -342,6 +342,8 @@ public:
     void folderRenamed(const QString &binId, const QString &folderName);
     /** @brief Open a file in a file manager, workaround needed for Flatpak crash https://bugs.kde.org/show_bug.cgi?id=486494 */
     void highlightFileInExplorer(QList<QUrl> urls);
+    /** @brief When a timeline operation changes the clip under the mouse cursor, inform the qml view */
+    void updateHoverItem(const QUuid &uuid);
 
 private:
     explicit Core(const QString &packageType);
